@@ -37,11 +37,11 @@ async def create_queues(queues, channel):
         logger.info('Declaring queue: %s', queue['name'])
         dlx_name = queue.get('dlx', f"{queue['name']}_dlx")
         dlq_name = queue.get('dlq', f"{queue['name']}_dlq")
+
         q_args = {
             **{"x-queue-type": queue.get("type", "quorum")},
             **queue.get("arguments", {})
         }
-
         await channel.declare_exchange(
             dlx_name,
             type=aio_pika.ExchangeType.TOPIC,
@@ -59,9 +59,14 @@ async def create_queues(queues, channel):
         )
         await dlq.bind(dlx_name, routing_key='#')
 
+        q_args = {
+            **{"x-queue-type": queue.get("type", "quorum")},
+            **{"x-dead-letter-exchange": queue.get('x-dead-letter-exchange', dlx_name)},
+            **queue.get("arguments", {})
+        }
         q_conns[queue['name']] = await channel.declare_queue(
             queue['name'],
-            arguments={"x-dead-letter-exchange": dlx_name, **q_args},
+            arguments={**q_args},
             durable=queue.get('durable', True),
             robust=queue.get('robust', True),
             auto_delete=queue.get('auto_delete', False),
